<?php

/**
 * SmartCouponIntegrations
 *
 * @link       https://appcheap.io
 * @since      4.2.0
 * @author     ngocdt
 * @package    AppBuilder
 */

defined( 'ABSPATH' ) || exit;

use Automattic\WooCommerce\StoreApi\Schemas\V1\CartSchema;

/**
 * SmartCouponIntegrations Class.
 */
class PaytmIntegrations implements IntegrationInterface {

	/**
	 * Integrations infomation.
	 *
	 * @var string $identifier infomation.
	 */
	public static $infomation = array(
		'identifier'    => 'PaytmPaymentGateway',
		'title'         => 'Paytm Payment Gateway',
		'description'   => 'Paytm Payment Gateway is ideal for Woocommerce and WordPress merchants since it allows them to give their customers a seamless, super-fast checkout experience backed by cutting-edge payments technology that powers India’s largest payments platform. Accept payments from over 100+ payment sources including credit cards, debit cards, netbanking from 50+ banks (including HDFC & SBI), UPI, wallets and Buy-now-pay-later options. Here are a few reasons why Woocommerce merchants should choose Paytm Payment Gateway.',
		'icon'          => 'https://ps.w.org/paytm-payments/assets/icon-128x128.png',
		'url'           => 'https://wordpress.org/plugins/paytm-payments/',
		'author'        => 'Paytm',
		'documentation' => 'https://wordpress.org/plugins/paytm-payments/',
		'category'      => 'Payment Gateway',
	);

	/**
	 * Register hooks.
	 */
	public function register_hooks() {
		add_action( 'woocommerce_rest_checkout_process_payment_with_context', array( $this, 'process_payment' ), 11, 2 );
	}

	/**
	 * Process payment
	 *
	 * @param  \PaymentContext $context The payment context.
	 * @param \PaymentResult  $result  The payment result.
	 *
	 * @return void
	 */
	public function process_payment( $context, &$result ) {
		if ( 'paytm' === $context->payment_method ) {
			$gateway = $context->get_payment_method_instance();

			$order    = $context->order;
			$order_id = $order->get_id();

			$order_id = PaytmHelper::getPaytmOrderId( $order_id );

			$getOrderInfo = $gateway->getOrderInfo( $order );

			if ( ! empty( $getOrderInfo['email'] ) ) {
				$cust_id = $email = $getOrderInfo['email'];
			} else {
				$cust_id = 'CUST_' . $order_id;
			}
			// get mobile no if there for DC_EMI
			if ( isset( $getOrderInfo['contact'] ) && ! empty( $getOrderInfo['contact'] ) ) {
				$cust_mob_no = $getOrderInfo['contact'];
			} else {
				$cust_mob_no = '';
			}
			$settings     = get_option( 'woocommerce_paytm_settings' );
			$checkout_url = str_replace( 'MID', $settings['merchant_id'], PaytmHelper::getPaytmURL( PaytmConstants::CHECKOUT_JS_URL, $settings['environment'] ) );

			$paramData = array(
				'amount'      => $getOrderInfo['amount'],
				'order_id'    => $order_id,
				'cust_id'     => $cust_id,
				'cust_mob_no' => $cust_mob_no,
			);
			$data      = $gateway->blinkCheckoutSend( $paramData );

			if ( isset( $data['txnToken'] ) && ! empty( $data['txnToken'] ) ) {
				$result->set_payment_details(
					array(
						'txnToken' => $data['txnToken'],
                        'order_id' => $order_id,
					)
				);
			}
		}
	}
}
